==> qwcore-2.0.4-sources.jar: com/livquik/qwcore/pojo/common/BaseRequest.java <==
package com.livquik.qwcore.pojo.common;

import org.parceler.Parcel;

/**
 * Created by turing on 3/8/15.
 */
@Parcel
public class BaseRequest {

    String partnerid;
    String signature;
    String mobile;

    String latitude;
    String longitude;
    String qwversion ;
    String sdkversion;
    String platform;

    String passphrase;
    String userid;

    String transactionId;

    /**
     * @param partnerid
     * @param signature
     * @param mobile
     * @param latitude
     * @param longitude
     * @param qwversion
     * @param passphrase
     * @param userid
     */
    public BaseRequest(String partnerid, String signature, String mobile, String latitude, String longitude, String qwversion, String passphrase, String userid) {
        this.partnerid = partnerid;
        this.signature = signature;
        this.mobile = mobile;
        this.latitude = latitude;
        this.longitude = longitude;
        this.qwversion = qwversion;
        this.passphrase = passphrase;
        this.userid = userid;
    }

    public BaseRequest(String userid, String latitude, String longitude, String passphrase, String qwversion) {
        this.userid = userid;
        this.latitude = latitude;
        this.longitude = longitude;
        this.passphrase = passphrase;
        this.qwversion = qwversion;
    }

    public BaseRequest(String partnerid, String signature, String mobile) {
        this.partnerid = partnerid;
        this.signature = signature;
        this.mobile = mobile;
    }

    public BaseRequest(String passphrase, String userid) {
        this.passphrase = passphrase;
        this.userid = userid;
    }

    public BaseRequest() {
    }

    public String getPartnerid() {
        return partnerid;
    }

    public void setPartnerid(String partnerid) {
        this.partnerid = partnerid;
    }

    public String getSignature() {
        return signature;
    }

    public void setSignature(String signature) {
        this.signature = signature;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getLatitude() {
        return latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }

    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getQwversion() {
        return qwversion;
    }

    public void setQwversion(String qwversion) {
        this.qwversion = qwversion;
    }

    public String getSdkversion() {
        return sdkversion;
    }

    public void setSdkversion(String sdkversion) {
        this.sdkversion = sdkversion;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public String getPassphrase() {
        return passphrase;
    }

    public void setPassphrase(String passphrase) {
        this.passphrase = passphrase;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getTransactionId() {
        return transactionId;
    }

    public void setTransactionId(String transactionId) {
        this.transactionId = transactionId;
    }


    @Override
    public String toString() {
        return "BaseRequest{" +
                "partnerid='" + partnerid + '\'' +
                ", signature='" + signature + '\'' +
                ", mobile='" + mobile + '\'' +
                ", latitude='" + latitude + '\'' +
                ", longitude='" + longitude + '\'' +
                ", qwversion='" + qwversion + '\'' +
                ", sdkversion='" + sdkversion + '\'' +
                ", platform='" + platform + '\'' +
                ", passphrase='" + passphrase + '\'' +
                ", userid='" + userid + '\'' +
                ", transactionId='" + transactionId + '\'' +
                '}';
    }
}

==> qwcore-3.0.1-sources.jar: com/livquik/qwcore/pojo/common/BaseRequest.java <==
package com.livquik.qwcore.pojo.common;

import org.parceler.Parcel;

/**
 * Created by turing on 3/8/15.
 */
@Parcel
public class BaseRequest {

    String partnerid;
    String signature;
    String mobile;

    String latitude;
    String longitude;
    String qwversion ;
    String sdkversion;
    String platform;

    String passphrase;
    String userid;

    String transactionId;

    String sessionid;
    String crnnumber;

    /**
     * @param partnerid
     * @param signature
     * @param mobile
     * @param latitude
     * @param longitude
     * @param qwversion
     * @param passphrase
     * @param userid
     */
    public BaseRequest(String partnerid, String signature, String mobile, String latitude, String longitude, String qwversion, String passphrase, String userid) {
        this.partnerid = partnerid;
        this.signature = signature;
        this.mobile = mobile;
        this.latitude = latitude;
        this.longitude = longitude;
        this.qwversion = qwversion;
        this.passphrase = passphrase;
        this.userid = userid;
    }

    public BaseRequest(String userid, String latitude, String longitude, String passphrase, String qwversion) {
        this.userid = userid;
        this.latitude = latitude;
        this.longitude = longitude;
        this.passphrase = passphrase;
        this.qwversion = qwversion;
    }

    public BaseRequest(String partnerid, String signature, String mobile) {
        this.partnerid = partnerid;
        this.signature = signature;
        this.mobile = mobile;
    }

    public BaseRequest(String passphrase, String userid) {
        this.passphrase = passphrase;
        this.userid = userid;
    }

    public BaseRequest() {
    }

    public String getPartnerid() {
        return partnerid;
    }

    public void setPartnerid(String partnerid) {
        this.partnerid = partnerid;
    }

    public String getSignature() {
        return signature;
    }

    public void setSignature(String signature) {
        this.signature = signature;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getLatitude() {
        return latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }

    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getQwversion() {
        return qwversion;
    }

    public void setQwversion(String qwversion) {
        this.qwversion = qwversion;
    }

    public String getSdkversion() {
        return sdkversion;
    }

    public void setSdkversion(String sdkversion) {
        this.sdkversion = sdkversion;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public String getPassphrase() {
        return passphrase;
    }

    public void setPassphrase(String passphrase) {
        this.passphrase = passphrase;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getTransactionId() {
        return transactionId;
    }

    public void setTransactionId(String transactionId) {
        this.transactionId = transactionId;
    }

    public String getSessionid() {
        return sessionid;
    }

    public void setSessionid(String sessionid) {
        this.sessionid = sessionid;
    }

    public String getCrnnumber() {
        return crnnumber;
    }

    public void setCrnnumber(String crnnumber) {
        this.crnnumber = crnnumber;
    }

    @Override
    public String toString() {
        return "BaseRequest{" +
                "partnerid='" + partnerid + '\'' +
                ", signature='" + signature + '\'' +
                ", mobile='" + mobile + '\'' +
                ", latitude='" + latitude + '\'' +
                ", longitude='" + longitude + '\'' +
                ", qwversion='" + qwversion + '\'' +
                ", sdkversion='" + sdkversion + '\'' +
                ", platform='" + platform + '\'' +
                ", passphrase='" + passphrase + '\'' +
                ", userid='" + userid + '\'' +
                ", transactionId='" + transactionId + '\'' +
                ", sessionid='" + sessionid + '\'' +
                ", crnnumber='" + crnnumber + '\'' +
                '}';
    }
}
